@@ -47,7 +47,7 @@ try:
         XArrayResamplerBilinear,
     )
 except ImportError:
-    warnings.warn("XArray, dask, and/or zarr not found, XArrayBilinearResampler won't be available.")
+    warnings.warn("XArray, dask, and/or zarr not found, XArrayBilinearResampler won't be available.", stacklevel=2)
     XArrayBilinearResampler = None
     CACHE_INDICES = None
     XArrayResamplerBilinear = None
