@@ -34,6 +34,7 @@ from pyresample import CHUNK_SIZE, _spatial_mp, data_reduce, geometry
 
 from .future.resamplers._transform_utils import lonlat2xyz
 from .future.resamplers.nearest import _my_index, query_no_distance
+from .utils.row_appendable_array import RowAppendableArray
 
 logger = getLogger(__name__)
 
@@ -301,7 +302,6 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
     segments : int or None
         Number of segments to use when resampling.
         If set to None an estimate will be calculated
-
     Returns
     -------
     (valid_input_index, valid_output_index,
@@ -310,7 +310,7 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
     """
     if source_geo_def.size < neighbours:
         warnings.warn('Searching for %s neighbours in %s data points' %
-                      (neighbours, source_geo_def.size))
+                      (neighbours, source_geo_def.size), stacklevel=2)
 
     if segments is None:
         cut_off = 3000000
@@ -339,8 +339,11 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
 
     if segments > 1:
         # Iterate through segments
-        for i, target_slice in enumerate(geometry._get_slice(segments,
-                                                             target_geo_def.shape)):
+        appendable_valid_output_index = RowAppendableArray(target_geo_def.size)
+        appendable_index_array = RowAppendableArray(target_geo_def.size)
+        appendable_distance_array = RowAppendableArray(target_geo_def.size)
+
+        for target_slice in geometry._get_slice(segments, target_geo_def.shape):
 
             # Query on slice of target coordinates
             next_voi, next_ia, next_da = \
@@ -352,20 +355,12 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
                                        reduce_data=reduce_data,
                                        nprocs=nprocs)
 
-            # Build result iteratively
-            if i == 0:
-                # First iteration
-                valid_output_index = next_voi
-                index_array = next_ia
-                distance_array = next_da
-            else:
-                valid_output_index = np.append(valid_output_index, next_voi)
-                if neighbours > 1:
-                    index_array = np.row_stack((index_array, next_ia))
-                    distance_array = np.row_stack((distance_array, next_da))
-                else:
-                    index_array = np.append(index_array, next_ia)
-                    distance_array = np.append(distance_array, next_da)
+            appendable_valid_output_index.append_row(next_voi)
+            appendable_index_array.append_row(next_ia)
+            appendable_distance_array.append_row(next_da)
+        valid_output_index = appendable_valid_output_index.to_array()
+        index_array = appendable_index_array.to_array()
+        distance_array = appendable_distance_array.to_array()
     else:
         # Query kd-tree with full target coordinate set
         full_slice = slice(None)
@@ -383,7 +378,7 @@ def get_neighbour_info(source_geo_def, target_geo_def, radius_of_influence,
         if not np.all(np.isinf(distance_array[:, -1])):
             warnings.warn(('Possible more than %s neighbours '
                            'within %s m for some data points') %
-                          (neighbours, radius_of_influence))
+                          (neighbours, radius_of_influence), stacklevel=2)
 
     return valid_input_index, valid_output_index, index_array, distance_array
 
@@ -820,7 +815,7 @@ def get_sample_from_neighbour_info(resample_type, output_shape, data,
     else:  # One channel
         output_raw_shape = output_size
 
-    full_result = np.ones(output_raw_shape) * fill_value
+    full_result = np.full(output_raw_shape, fill_value, dtype=result.dtype)
     full_result[valid_output_index] = result
     result = full_result
 
@@ -980,7 +975,7 @@ class XArrayResamplerNN(object):
         """
         if self.source_geo_def.size < self.neighbours:
             warnings.warn('Searching for %s neighbours in %s data points' %
-                          (self.neighbours, self.source_geo_def.size))
+                          (self.neighbours, self.source_geo_def.size), stacklevel=2)
 
         # Create kd-tree
         chunks = mask.chunks if mask is not None else CHUNK_SIZE
