@@ -123,6 +123,18 @@ class Test(unittest.TestCase):
         expected = 15874591.0
         self.assertEqual(cross_sum, expected)
 
+    def test_nearest_complex(self):
+        data = np.fromfunction(lambda y, x: y + complex("j") * x, (50, 10), dtype=np.complex_)
+        lons = np.fromfunction(lambda y, x: 3 + x, (50, 10))
+        lats = np.fromfunction(lambda y, x: 75 - y, (50, 10))
+        swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
+        res = kd_tree.resample_nearest(swath_def, data.ravel(),
+                                       self.area_def, 50000, segments=1)
+        assert np.issubdtype(res.dtype, np.complex_)
+        cross_sum = res.sum()
+        assert cross_sum.real == 3530219.0
+        assert cross_sum.imag == 688723.0
+
     def test_nearest_masked_swath_target(self):
         """Test that a masked array works as a target."""
         data = np.fromfunction(lambda y, x: y * x, (50, 10))
